-----------------------------------------------
-- Licensed Materials - Property of IBM
--
-- 5724-R31, 5655-S30
--
-- (C) Copyright IBM Corp. 2006, 2008 All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
------------------------------------------------



  CREATE TABLE W_LIT_DOUBLE 
   (	ID NUMBER(*,0), 
	LITVAL FLOAT(126)
   ) ;
  ALTER TABLE W_LIT_DOUBLE ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX idx_obj_dbl ON w_lit_double (litval);
 
  CREATE TABLE W_LIT_FLOAT 
   (	ID NUMBER(*,0), 
	LITVAL FLOAT(63)
   ) ;
  ALTER TABLE W_LIT_FLOAT ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX idx_obj_flt ON w_lit_float (litval);
 
  CREATE TABLE W_LIT_LONG 
   (	ID NUMBER(*,0), 
	LITVAL NUMBER(38,0)
   ) ;
  ALTER TABLE W_LIT_LONG ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX idx_obj_long ON w_lit_long (litval);
 
  CREATE TABLE W_NAMESPACE 
   (	ID NUMBER(*,0), 
	NAMESPACE VARCHAR2(254) NOT NULL ENABLE
   ) ;
  ALTER TABLE W_NAMESPACE ADD PRIMARY KEY (ID) ENABLE;
 
  CREATE TABLE W_OBJ_LIT_ANY 
   (	ID NUMBER(*,0), 
	LARGE BLOB, 
	HASH VARCHAR2(40), 
	TYPE_URI VARCHAR2(254) NOT NULL ENABLE
   ) ;
  ALTER TABLE W_OBJ_LIT_ANY ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX idx_obj_any ON w_obj_lit_any (type_uri);
 
  CREATE TABLE W_OBJ_LIT_DATE 
   (	ID NUMBER(*,0), 
	LITVAL TIMESTAMP (6)
   ) ;
  ALTER TABLE W_OBJ_LIT_DATE ADD PRIMARY KEY (ID) ENABLE;
 
  CREATE INDEX idx_obj_date ON w_obj_lit_date (litval);

  CREATE TABLE W_OBJ_LIT_DATETIME 
   (	ID NUMBER(*,0), 
	LITVAL TIMESTAMP (6)
   ) ;
  ALTER TABLE W_OBJ_LIT_DATETIME ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX idx_obj_time ON w_obj_lit_datetime (litval);

 
  CREATE TABLE W_OBJ_LIT_STRING 
   (	ID NUMBER(*,0), 
	LARGE BLOB, 
	LITVAL VARCHAR2(1024), 
	HASH VARCHAR2(40)
   ) ;
  ALTER TABLE W_OBJ_LIT_STRING ADD PRIMARY KEY (ID) ENABLE;

  CREATE INDEX idx_obj_str ON w_obj_lit_string (hash);
 
  CREATE TABLE W_STATEMENT 
   (	ID NUMBER(*,0), 
	VERSION_FROM NUMBER(*,0) NOT NULL ENABLE, 
	VERSION_TO NUMBER(*,0) NOT NULL ENABLE, 
	SUBJ_ID NUMBER(*,0) NOT NULL ENABLE, 
	PRED_ID NUMBER(*,0) NOT NULL ENABLE, 
	OBJ_ID NUMBER(*,0) NOT NULL ENABLE, 
	OBJ_TYP_CD NUMBER(*,0) NOT NULL ENABLE,
	PARTITION_ID NUMBER(*,0) NOT NULL ENABLE
   ) ;
  ALTER TABLE W_STATEMENT ADD PRIMARY KEY (ID) ENABLE;
  
  CREATE INDEX idx_smt_by_sbj ON w_statement (subj_id, version_from, version_to);
  CREATE INDEX idx_smt_by_fvr ON w_statement (version_from);
  CREATE INDEX idx_sbj_by_prp ON w_statement (pred_id, obj_id);
  CREATE INDEX idx_smt_by_val ON w_statement (obj_id, subj_id);
  CREATE INDEX idx_val_by_prp ON w_statement (subj_id, pred_id);
 
  CREATE TABLE W_URI 
   (	ID NUMBER(*,0), 
	URI VARCHAR2(254) NOT NULL ENABLE, 
	NAMESPACE_ID NUMBER(*,0) NOT NULL ENABLE
   ) ;
  ALTER TABLE W_URI ADD PRIMARY KEY (ID) ENABLE;
  ALTER TABLE W_URI ADD CONSTRAINT W_URI_FK_NAMESP FOREIGN KEY (NAMESPACE_ID)
	  REFERENCES W_NAMESPACE (ID) ENABLE;
 
  CREATE TABLE W_VERSION 
   (	USERNAME VARCHAR2(64) NOT NULL ENABLE, 
	CHANGE_TIME TIMESTAMP (6) NOT NULL ENABLE, 
	CL_GID VARCHAR2(36), 
	CL_LID VARCHAR2(10), 
	SCHEMA_NS_ID NUMBER(*,0), 
	SCHEMA_REV NUMBER(*,0), 
	ID NUMBER(*,0) NOT NULL ENABLE,
	PARTITION_ID NUMBER(*,0) NOT NULL ENABLE
   ) ;
  ALTER TABLE W_VERSION ADD PRIMARY KEY (ID, PARTITION_ID) ENABLE;
  ALTER TABLE W_VERSION ADD CONSTRAINT W_VER_FK_NAMESP FOREIGN KEY (SCHEMA_NS_ID)
	  REFERENCES W_NAMESPACE (ID) ENABLE;

  CREATE INDEX idx_ver_schema ON w_version (schema_ns_id);

CREATE TABLE W_ARTIFACT_BLOB 
(
 ID VARCHAR2(254) NOT NULL, 
 CONTENT BLOB, 
 DELETED NUMBER(1,0)
);
ALTER TABLE W_ARTIFACT_BLOB ADD PRIMARY KEY (ID) ENABLE;

CREATE UNIQUE INDEX IDX_URI ON W_URI (URI);
CREATE UNIQUE INDEX IDX_URI_BY_NS ON W_URI (NAMESPACE_ID, ID);

CREATE UNIQUE INDEX IDX_NAMESPACE ON W_NAMESPACE (NAMESPACE);

CREATE SEQUENCE  SEQ_W_LIT_DOUBLE_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_LIT_FLOAT_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_LIT_LONG_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_NAMESPACE_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_OBJ_LIT_ANY_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_OBJ_LIT_DATE_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_OBJ_LIT_DATETIME_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_OBJ_LIT_STRING_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_STATEMENT_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

CREATE SEQUENCE  SEQ_W_URI_ID  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 20 NOORDER  NOCYCLE ;

  CREATE TABLE W_LOCALE
  (	   ID NUMBER(*,0),
       LOCALE VARCHAR2(8)
  ) ;
  
  ALTER TABLE W_LOCALE ADD PRIMARY KEY (ID) ENABLE;

  ALTER TABLE W_LOCALE ADD CONSTRAINT UNIQUE_LOCALE UNIQUE (LOCALE);
  
  INSERT INTO W_LOCALE VALUES (1000, 'root');

  INSERT INTO W_LOCALE VALUES (1001, 'en');

  INSERT INTO W_LOCALE VALUES (1002, 'en-us');
 
  INSERT INTO W_LOCALE VALUES (1003, 'en-uk');
  
  INSERT INTO W_LOCALE VALUES (1004, 'en-gb');

  INSERT INTO W_LOCALE VALUES (1032, 'cs');

  INSERT INTO w_locale VALUES (1064, 'es');

  INSERT INTO w_locale VALUES (1096, 'de');

  INSERT INTO w_locale VALUES (1128, 'de-de');

  INSERT INTO w_locale VALUES (1129, 'fr');

  INSERT INTO w_locale VALUES (1160, 'fr-ca-sk');

  INSERT INTO w_locale VALUES (1161, 'hu');

  INSERT INTO w_locale VALUES (1192, 'it');

  INSERT INTO w_locale VALUES (1224, 'ja');

  INSERT INTO w_locale VALUES (1256, 'ko');

  INSERT INTO w_locale VALUES (1288, 'pl');

  INSERT INTO w_locale VALUES (1320, 'pt-br');

  INSERT INTO w_locale VALUES (1352, 'ru');

  INSERT INTO w_locale VALUES (1384, 'zh');

  INSERT INTO w_locale VALUES (1416, 'zh-tw');

  INSERT INTO w_locale VALUES (1448, 'el');



CREATE TABLE w_subj_pred_index (
    subj_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    predicate_map RAW(1024),
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (subj_id, version_from, version_to, partition_id)
);

CREATE TABLE w_subj_obj_index (
    subj_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    object_map RAW(1024),
    obj_typ_cd NUMBER(*,0) NOT NULL,
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (subj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE w_pred_subj_index (
    pred_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    subject_map RAW(1024),
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (pred_id, version_from, version_to, partition_id)
);

CREATE TABLE w_pred_obj_index (
    pred_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    object_map RAW(1024),
    obj_typ_cd NUMBER(*,0) NOT NULL,
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (pred_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE w_obj_subj_index (
    obj_id NUMBER(*,0) NOT NULL,
    obj_typ_cd NUMBER(*,0) NOT NULL,
    subject_map RAW(1024),
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE w_obj_pred_index (
    obj_id NUMBER(*,0) NOT NULL,
    obj_typ_cd NUMBER(*,0) NOT NULL,
    predicate_map RAW(1024),
    version_from NUMBER(*,0) NOT NULL,
    version_to NUMBER(*,0) NOT NULL,
    partition_id NUMBER(*,0) NOT NULL REFERENCES w_uri (id),
    PRIMARY KEY (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);




  CREATE TABLE W_DBVERSION  
  (	  SUBSYSTEM VARCHAR2(8) NOT NULL ENABLE, 
	  CUR_VERSION NUMBER(*,0) NOT NULL ENABLE   
  ) ;
  ALTER TABLE W_DBVERSION ADD PRIMARY KEY (SUBSYSTEM) ENABLE;
